#!/usr/bin/env python

import subprocess
import sys
import config
import optparse
from notify import get_user_emails,get_state,send_nrdp_notifications,send_traps,run_local_cmds,send_email
from netflow_checks import update_check_db
import optparse
import re
import syslog
import logging

logger = logging.getLogger('backend')

def get_path_check_info(check_id):
    QUERY = '''
SELECT 
    `nagiosna_Checks`.`name` as check_name, 
    `nagiosna_path_nodes`.`name` as target_name, 
    `nagiosna_Checks`.`metric` as metric
FROM
    nagiosna_Checks
INNER JOIN
    nagiosna_path_nodes
ON 
    nagiosna_Checks.pid = nagiosna_path_nodes.id
WHERE
    `nagiosna_Checks`.`cid` = '%s'
''' % check_id
    print(QUERY)
    check_infos = config.query_database(QUERY)
    if len(check_infos) == 0:
        # TODO: probably raise an exception instead?
        return ('<internal error>', '<internal error>', '<internal error>')
    print(check_infos)
    check_info = check_infos[0]
    return check_info


def send_path_emails(check_id, last_good_hostname, hop_number, returncode):

    global logger
    contact_info = get_user_emails(check_id)
    check_name, target_name, metric_name = get_path_check_info(check_id)

    metric_nice_names = {
        'lost_connection': 'connectivity',
        'rtt': 'round-trip time'
    }
    metric_nice_name = metric_nice_names[metric_name]

    body = '''
%%s,

The check %s alerted while evaluating the route to %s for %s.

The last known good intermediate node was %s, at hop number %s.

- Nagios Network Analyzer''' % (check_name, target_name, metric_nice_name, last_good_hostname, hop_number)

    subject = '%s: %s on %s' % (get_state(returncode), metric_name, check_name)
    for email, firstname, lastname in contact_info:
        name = "%s %s" % (firstname, lastname)
        specific = body % name

        # Try to send email
        try:
            send_email(email, subject, specific)
        except Exception:
            logger.exception('Could not send email to %s' % email)
            continue

def main(options=None):
    
    if len(sys.argv) != 6:
        raise Exception('Usage: %s check_id hostname hop_number returncode stdout' % sys.argv[0])
    args = sys.argv[1:]

    check_id, hostname, hop_number, returncode, stdout = args

    update_check_db(check_id, stdout, 0, returncode)

    if returncode != 0:
        send_path_emails(check_id, hostname, hop_number, returncode)    
        send_nrdp_notifications(check_id, stdout, returncode)
        send_traps(hostname, check_id, returncode, stdout)
        run_local_cmds(hostname, check_id, returncode, stdout)


if __name__ == '__main__':
    main()
