#!/bin/bash
#
# Bash script that changes the timezone of the server
# Copyright 2014-2020 Nagios Enterprises, LLC. All Rights reserved.
#

PATH=$PATH:/sbin:/usr/sbin

###############################
# USAGE / HELP
###############################
usage () {
	echo ""
	echo "Use this script change your Timezone for your Nagios Network Analyzer system. (PHP and Localtime)"
	echo "Copyright 2014-2020 Nagios Enterprises, LLC. All Rights reserved."
	echo ""
	echo " -z | --zone             	The Posix & PHP supported timezone you want to change to"
	echo "                                  Example Timezone: America/Chicago"
	echo ""
	echo " -h | --help             	Show the help section"
	echo ""
}

###############################
# GET THE VARIABLES
###############################
while [ -n "$1" ]; do
	case "$1" in
		-h | --help)
			usage
			exit 0
			;;
		-z | --zone)
			TZONE=$2
			;;
	esac
	shift
done

if [ "x$TZONE" == "x" ] || [ ! -e /usr/share/zoneinfo/$TZONE ]; then
	echo "You must enter a proper time zone to change to (i.e. America/Chicago)"
	exit 1
fi

# Set the sysconfig clock time
if [ -e /etc/sysconfig/clock ]; then
	echo 'ZONE="'$TZONE'"' > /etc/sysconfig/clock
fi

# Set the localtime
ln -sf /usr/share/zoneinfo/$TZONE /etc/localtime

# Find proper php ini
phpinitest=( "/etc/php.ini" "/etc/php5/apache2/php.ini" "/etc/php/7.0/apache2/php.ini" "/etc/php/7.1/apache2/php.ini"  "/etc/php/7.2/apache2/php.ini" "/etc/php/7.3/apache2/php.ini" "/etc/php/7.4/apache2/php.ini" )
for f in "${phpinitest[@]}"
do
	if [ -f "$f" ]; then
		phpini="$f"
	fi
done

# Set the PHP timezone
cp -f $phpini $phpini.backup
sed -ri "s~^;?date\.timezone *=.*~date.timezone = $TZONE~" $phpini

# sleep for 2 seconds
sleep 2

# Restart apache and databases to make sure timezone is properly set
if [ ! `command -v systemctl` ]; then
	service httpd restart
	service mysqld restart
else
	if [ -f /usr/sbin/apache2 ]; then
		systemctl restart apache2
	else
		systemctl restart httpd
	fi

	# Restart mariadb or mysql...
	if rpm -q mariadb-server 2>/dev/null ; then
		systemctl restart mariadb
	else
		systemctl restart mysqld
	fi

	# Restart php-fpm if it exists on the system
	if rpm -q php-fpm 2>/dev/null ; then
		systemctl restart php-fpm
	fi
fi

echo 'All timezone configurations updated to "'$TZONE'"'